Exception: AdequateSerialization::CacheBusting::ActiveJobNotFoundError
- Inherits:
-
Error
- Object
- StandardError
- Error
- AdequateSerialization::CacheBusting::ActiveJobNotFoundError
- Defined in:
- lib/adequate_serialization/rails/cache_busting.rb
Instance Method Summary collapse
-
#initialize(record, association) ⇒ ActiveJobNotFoundError
constructor
A new instance of ActiveJobNotFoundError.
Constructor Details
#initialize(record, association) ⇒ ActiveJobNotFoundError
Returns a new instance of ActiveJobNotFoundError.
29 30 31 32 33 34 35 36 37 |
# File 'lib/adequate_serialization/rails/cache_busting.rb', line 29 def initialize(record, association) super(" In order to be able to bust the associated cache for \#{record}'s\n `\#{association}` association, AdequateSerialization enqueues a\n background job (since there are potentially multiple records on the\n association). In order to use the background job, it must have access\n to ActiveJob.\n MSG\nend\n") |